AGENT_DISCOVERY_URL = "/com.instana.plugin.python.discovery"
AGENT_TRACES_URL = "/com.instana.plugin.python/traces."
AGENT_DATA_URL = "/com.instana.plugin.python."
AGENT_DEFAULT_HOST = "localhost"
AGENT_DEFAULT_PORT = 42699
AGENT_HEADER = "Instana Agent"
